@@ -5,5 +5,8 @@ from .builtin import *
 from .errors import *
 from .util import *
 
-__version__ = '0.2.0'
+from .grammar import *
+from .parser import *
+
+__version__ = '0.2.1'
 __author__ = 'jay3332'
